#
# spec file for package ddclient
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           ddclient
Version:        3.10.0
Release:        150000.3.10.3
Summary:        A Perl Client to Update Dynamic DNS Entries
License:        GPL-2.0-or-later
Group:          Productivity/Networking/DNS/Utilities
URL:            https://github.com/ddclient/ddclient
Source0:        https://github.com/ddclient/ddclient/archive/v%{version}/%{name}-%{version}.tar.gz
Source1:        %{name}.service
Source2:        %{name}.sysconfig
Source3:        %{name}-tmpfiles.conf
Patch0:         %{name}-config.patch
Patch1:         %{name}-delay-main-process-for-systemd.patch
Patch2:         fix-configure_ac.patch
Patch3:         disable-ip-test.patch
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  curl
BuildRequires:  make
BuildRequires:  perl(HTTP::Daemon)
BuildRequires:  perl(IO::Socket::SSL)
BuildRequires:  perl(Test::MockModule)
BuildRequires:  perl(Test::Warnings)
Requires:       curl
Requires:       perl >= 5.10.1
Requires(pre):  %fillup_prereq
Requires(pre):  shadow
Recommends:     perl-IO-Socket-SSL
BuildArch:      noarch
%{?systemd_requires}

%description
ddclient is a client requiring only Perl. Supported
features include daemon operation, manual and automatic updates, static
and dynamic updates, optimized updates for multiple addresses, MX, wild
cards, abuse avoidance, retry for failed updates, and status updates to
syslog and through e-mail. ddclient can obtain the IP address from any
interface, through a Web-based IP detection service, and for multiple
routers using custom FW definitions. It also provides full support for
DynDNS.org's NIC2 protocol. Support is also included for other dynamic
DNS services. Comes with sample scripts for use with DHCP, PPP, and
cron.

%prep
%autosetup -p1
rm -f sample-etc_ddclient.conf.orig
chmod a-x sample-*
mkdir examples
mv sample-* examples

%build
./autogen
%configure
make

%install
%make_install
find examples -name *exe -delete
mkdir -p %{buildroot}%{_sbindir}/
mv %{buildroot}%{_bindir}/%{name} %{buildroot}%{_sbindir}/%{name}
sed -i -e "s,%{_localstatedir}/run/,/run/%{name}/," %{buildroot}%{_sysconfdir}/%{name}.conf
install -D -m 644 %{SOURCE1} %{buildroot}/%{_unitdir}/%{name}.service
install -D -m 644 %{SOURCE3} %{buildroot}%{_tmpfilesdir}/%{name}.conf
ln -s service %{buildroot}%{_sbindir}/rc%{name}
install -d -m 755 %{buildroot}%{_fillupdir}
install -m 644 %{SOURCE2} %{buildroot}%{_fillupdir}/sysconfig.%{name}
install -d -m 755 %{buildroot}%{_localstatedir}/cache/%{name}
install -d -m 755 %{buildroot}/run/%{name}

%check
make VERBOSE=1 check

%pre
getent group %{name} >/dev/null || %{_sbindir}/groupadd -r %{name}
getent passwd %{name} >/dev/null || \
  %{_sbindir}/useradd -c "DDClient User" -d %{_localstatedir}/cache/%{name} \
    -g %{name} -r -s /bin/false %{name}
%service_add_pre %{name}.service

%post
%fillup_only
%tmpfiles_create %{_tmpfilesdir}/%{name}.conf
%service_add_post %{name}.service

%preun
%service_del_preun %{name}.service

%postun
%service_del_postun %{name}.service

%files
%doc COPY* README* examples
%config(noreplace) %attr(600,%{name},root) %{_sysconfdir}/%{name}.conf
%{_unitdir}/%{name}.service
%{_tmpfilesdir}/ddclient.conf
%ghost %dir %attr(755,%{name},%{name}) /run/%{name}
%{_sbindir}/%{name}
%{_sbindir}/rc%{name}
%{_fillupdir}/sysconfig.%{name}
%dir %attr(700,%{name},root) %{_localstatedir}/cache/%{name}

%changelog
* Mon Dec 18 2023 valentin.lefebvre@suse.com
- Remove buildRequires to perl(HTTP::Message::PSGI) not available and needed
  only for tests.
* Sun Jan  1 2023 munix9@googlemail.com
- Add curl as BuildRequires/Requires to be able to use the '-curl'
  option (eg. in DDCLIENT_OPTIONS in /etc/sysconfig/ddclient).
* Tue Dec 27 2022 info@paolostivanin.com
- Update to 3.10.0:
  * Added support for domaindiscount24.com
  * Added support for njal.la
  * Added support for Cloudflare API tokens
  * Added support for OVH DynHost.
  * Added support for ClouDNS.
  * Added support for dinahosting.
  * Added support for Gandi LiveDNS.
  * The freedns protocol (for https://freedns.afraid.org) now supports IPv6
    addresses.
  * New ssl_ca_dir and ssl_ca_file options to specify the location of CA
    certificates.
  * New built-in IP discovery service shorthands:
    + googledomains from https://domains.google
    + he from https://he.net
    ip+4only.me, ip6only.me from http://whatismyv6.com
    + ipify-ipv4 and ipify-ipv6 from https://www.ipify.org
    + myonlineportal from https://myonlineportal.net
    + noip-ipv4 and noip-ipv6 from https://www.noip.com
    + nsupdate.info-ipv4 and nsupdate.info-ipv6 from
    + https://www.nsupdate.info
    + zoneedit from https://www.zoneedit.com
  * Added option -curl to access network with system Curl command instead
    of the Perl built-in IO::Socket classes.
  * Added option -{no}web-ssl-validate and -{no}fw-ssl-validateto provide
    option to disable SSL certificate validation. Note that these only apply for
    network access when obtaining an IP address with use=web or use=fw
    (any firewall). Network access to Dynamic DNS servers to set or retrieve
    IP address will always require certificate validation.
  * The fw-banlocal option is deprecated and no longer does anything.
  * The if-skip option is deprecated and no longer does anything.
  * The default server for the dslreports1 protocol changed from
    members.dyndns.org to www.dslreports.com.
  * Removed support for defunct dnsspark service
  * Removed support for defunct dtdns service
  * Removed support for defunct Hammernode service
- Add fix-configure_ac.patch
- Add disable-ip-test.patch
- Rebase ddclient-config.patch
- Rebase ddclient-delay-main-process-for-systemd.patch
* Tue Jul 12 2022 chris@computersalat.de
- fix for boo#1191885
  add SupplementaryGroups=maildrop to service file
- rename ddclient-3.8.1-config.patch to ddclient-config.patch
- rebase patch
  * ddclient-delay-main-process-for-systemd.patch (p0)
- update ddclient-config.patch
  * fix PID file path
- merge ddclient-replace-varrun-with-run.patch into
  ddclient-config.patc
- merge changes file with SLES Maintained pkg
- update Source to %%{name}-%%{version}
* Fri Dec 24 2021 alarrosa@suse.com
- Modify the systemd service file so ddclient is run After
  network-online.target instead of just network.target, since
  running ddclient without being online is pointless.
- Added a Wants statement for the same systemd targets as in After
* Wed Sep  1 2021 jsegitz@suse.com
- Added hardening to systemd service(s). Modified:
  * ddclient.service
* Tue May 18 2021 josef.moellers@suse.com
- Systemd expects the PID file to exist as soon as the main process
  exists. However, it takes quite a while until the pid file is
  created by the daemon process, so we delay the main process
  for 1 second before exit()ing.
  This gets rid of an annoying warning message in "systemctl
  status".
  [ddclient, ddclient-delay-main-process-for-systemd.patch]
* Wed May 12 2021 josef.moellers@suse.com
- Use an extended regular expression in sed to change (/var)?/run.
* Thu Apr 22 2021 josef.moellers@suse.com
- In the (sample) /etc/ddclient.conf, also replace /var/run with /run.
  [ddclient-replace-varrun-with-run.patch, bsc#1185069]
* Wed Apr 21 2021 josef.moellers@suse.com
- /var/run is deprecated, replaced by /run in ddclient-tmpfiles.conf
  [ddclient-tmpfiles.conf, bsc#1185069]
* Wed Aug 19 2020 dimstar@opensuse.org
- Use %%{_tmpfilesdir} instead of abusing %%{_libexecdir}.
* Mon Feb  3 2020 tchvatal@suse.com
- Use properly tmpfiles-create
- Remove the systemd conditional
- Fixup download url
* Sun Feb  2 2020 kukuk@suse.com
- Replace pwdutils with shadow, former is gone long time ago
* Fri Jan 24 2020 mmanu84@outlook.de
- Upgrade to ddclient-3.9.1
  * added support for Yandex.Mail for Domain DNS service
  * added support for NearlyFreeSpeech.net
  * added support for DNS Made Easy
  * added systemd instructions
  * added support for dondominio.com
  * updated perl instruction
  * updated fritzbox instructions
  * fixed multidomain support for namecheap
  * fixed support for Yandex
* Tue Dec 31 2019 chris@computersalat.de
- fix for boo#1127387
  * systemd-tmpfiles need updating from /var/run/* to /run/*
* Sat Feb 16 2019 jengelh@inai.de
- Ensure neutrality of description.
- Do not ignore errors from useradd.
- Avoid %%__-type macro indirection.
* Mon Oct  1 2018 obs@botter.cc
- Require perl-Data-Validate-IP
* Thu Sep 13 2018 projects@localside.net
- Upgrade to ddclient-3.9.0
  * Support IPv6 for CloudFlare
  * name cheap support https now
  * Use JSON::PP instead of the (deprecated) JSON::Any
  * Specify port number properly to 'nsupdate'
  * Adding support for freemyip.com
* Thu Nov 23 2017 rbrown@suse.com
- Replace references to /var/adm/fillup-templates with new
  %%_fillupdir macro (boo#1069468)
* Fri Feb  3 2017 josef.moellers@suse.com
- Upgrade to ddclient-3.8.3.
  * added Alpine Linux init scritp - patch send by @Tal on github.
  * adding support for nsupdate - patch send by @droe on github
  * allow log username-password combinations - patch send by @dirdi on github
  * adding support for cloudflare - patch send by @roberthawdon on github
  * adding support for duckdns - patch send by @gkranis
* Fri Jan  8 2016 chris@computersalat.de
- fix for boo#903588
- revert patch change
- recover deleted changes (rev34)
- systemd fix
  * conf file must be accessible only by its owner
* Mon Jun 30 2014 pth@suse.de
- Use perl_requires instead of harcoding a value.
* Wed Jun 18 2014 stefan.fent@suse.com
- fix pidfile path in /etc/ddclient.conf and set ownership to ddclient
- create user and group ddclient (bnc#881520)
- create /run/ddclient/ with user and group ddclient if not yet
  available in %%pre
* Thu May 22 2014 chris@computersalat.de
- update systemd stuff
  * add {?has_systemd} to fix build for Systems using init scripts
- spec cleanup
  * add missing BuildRoot
* Tue May 20 2014 jsegitz@novell.com
- ensure proper handling of .service files with %%service_add_pre
* Tue Dec 31 2013 benoit.monin@gmx.fr
- update to 3.8.2
  * adding support by ChangeIP
  * sha-1 patch  to allow Digest::SHA
  * allow reuse of use
  * preventing deep sleep - see bug #46
  * Fallback to iproute if ifconfig doesn't work
- drop ddclient-3.8.1-update_nic.patch: upstream changed the "use"
  logic
- move all sample-* to examples under the documentation directory
- update source url on sourceforge
* Wed Dec  4 2013 seife+obs@b1-systems.com
- fix the breakage from last submission:
  * service file was put into tmpfiles.d
  * tmpfiles config was put into systemd service dir
  * rcddclient link was broken (pointed to "service" file)
- fix rpmlint warnings, also introduced by last submission:
  * service files and tmpdir config are neither config files nor
    should be executable
- package is noarch, mark it as such
- documentation should not have executable bit set
* Sun Oct 27 2013 p.drouand@gmail.com
- Improve systemd support for openSUSE >= 12.3
* Thu May 16 2013 seife+obs@b1-systems.com
- more init-script fixes:
  - startproc now needs the pidfile parameter (or it woulld look
    for "perl.pid". Sorry, should have run more tests.
  - while I'm at it, get the pidfile from the config file in case
    the user would have changed it
* Wed May 15 2013 seife+obs@b1-systems.com
- fix init script: start ddclient with "/usr/bin/perl ddclient",
  otherwise startproc will falsely report that starting failed.
* Wed Oct 24 2012 chris@computersalat.de
- rework config patch
  * ddclient.conf: add example for selfhost (http://selfhost.de)
* Tue Sep 25 2012 binli@opensuse.org
- Update ddclient-3.8.1-config.patch to check the configuraton file
  from /etc instead of /etc/ddclient (bnc#781699).
* Mon Jan  9 2012 chris@computersalat.de
- update to 3.8.1
  * Fixing #28: FreeDNS.afraid.org changed api slightly
  * Added dtdns-support
  * Added support for longer password
  * Added cisco-asa patch
  * Added support for LoopiaDNS
- rebase patches
* Wed Oct 19 2011 ro@suse.de
- remove leftover debug line in init script
* Sat Oct 15 2011 ro@suse.de
- upgrade Suggests for perl-IO-Socket-SSL to Recommends
  (bnc#723688)
* Sun Sep 18 2011 jengelh@medozas.de
- Remove redundant tags/sections from specfile
  (cf. packaging guidelines)
* Mon Aug 29 2011 ro@suse.de
- work on init-script so that start/status/stop at least work
  (bnc#267306)
* Tue Sep  1 2009 chris@computersalat.de
- rework config patch
  o now one patch
  o merged
  - ddclient-3.6.3-config.patch
  - ddclient-3.7.1-config.patch
  - ddclient-3.7.1-sysconfig.patch
    to ddclient-3.8.0-config.patch
  o defaults for ppp0
- added update_nic.patch
  * opt('use') should have priority to global-defaults
- init script
  o beautify
  o should start rp-pppoe
  o ppp0 as a "use=" default if not set in ddclient.conf
- sysconfig
  o added argument list for DDCLIENT_OPTIONS
- cleanup spec
* Sun Aug 30 2009 coolo@novell.com
- use %%patch0
* Wed Aug 26 2009 mls@suse.de
- make patch0 usage consistent
* Mon Feb  2 2009 kssingvo@suse.de
- made rpmlint more happy
- removed unneccessary .orig file to avoid build issue
* Wed Jan 28 2009 kssingvo@suse.de
- new version 3.8.0:
  * better password handling
  * ddclient wrapper now included
  * some remarks concerning postscript in sample config file
  * support for multiple IP adresses
  * namecheap patch
  * Preventing error while reading cache when ip wasn't set correctly
    before
  * Preventing an error when trying to send a message on mail-failure
  * mail-on-kill functionality
  * documentation changes
* Tue Jan 27 2009 kukuk@suse.de
- Add PreRequires
* Thu Aug 30 2007 kssingvo@suse.de
- config file ddclient.conf now with noreplace (bugzilla#305533)
* Tue Aug  7 2007 kssingvo@suse.de
- upgrade to version 3.7.3:
  * fixed typo for dnspark
  * Renamed dyndns.org to dyndns.com
  * opendns support added
  * several debian/ubuntu patches included
  * Readme changes
  * signature modified
  * typo in namecheap support
* Thu Jun 14 2007 kssingvo@suse.de
- upgrade to version 3.7.2:
  * updated easydns support
  * fix for 'fw' in case of debug
  * ssl call changed
  * easydns.patch and eurodns.patch now included
- enable_fw patch removed, now in upstream version included
* Thu May  3 2007 kssingvo@suse.de
- added sysconfig file, as suggested in bugzilla#268138
- added /var/cache/ddclient (bugzilla#268138)
* Tue Apr  3 2007 kssingvo@suse.de
- fixed issue in debug messages (bugzilla#250170)
* Tue Feb 13 2007 kssingvo@suse.de
- disabled ssl in default config (bugzilla#232005)
* Mon Feb 12 2007 kssingvo@suse.de
- update to version 3.7.1:
  * URL of zoneedit has changed (see bug #1558483)
  * Added initscript for Ubuntu (posted by Paolo Martinelli)
  * Added patch "Patch: Treat --daemon values as intervals"
    (submitted by James deBoer)
  * Don't send any mail when in not running daemon mode (patch
    submitted by Daniel Thaler)
  * Changed Changelog syntax
  * Applied patches submitted by Torsten:
    abuse_msg.diff: ddclient still reports the email to contact
    dyndns.org but they prefer a web form today (IIRC). This patch
    adjusts the abuse warning printed by ddclient.
    cachedir.diff: Original ddclient stores a cache file in /etc
    which would belong in /var/cache in my opinion and according
    to the FHS.
    help_nonroot.diff: Allow calling the help function as non-root.
    update-new-config.patch: Force update if config has changed
    smc-barricade-7401bra.patch: Support for SMC Barricade 7401BRA
    FW firewall
    cisco_fw.diff: Use configured hostname for firewall access with
  - use=cisco (closes: #345712). Thanks to Per Carlson for the
    patch!  See http://bugs.debian.org/345712.
    maxinterval.diff: Increase max interval for updates.
    See http://bugs.debian.org/cgi-bin/bugreport.cgi?bug=129370
    http://www.dyndns.com/support/services/dyndns/faq.html#q15
- added Suggests: for perl-IO-SSL-Socket (bugzilla#232005)
- adapted /etc config patch to new version
* Mon Jan  8 2007 kssingvo@suse.de
- fixed checkproc in init script (bugzilla#229460)
* Wed Sep 20 2006 kssingvo@suse.de
- added init script (bugzilla#201548)
* Wed Jun 28 2006 kssingvo@suse.de
- update to version 3.7.0:
- support of many new routers
- fix to have a '#' char in the password
- renamed .orig to _orig in %%doc section
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Wed Jan 11 2006 kssingvo@suse.de
- update to version 3.6.7
* Tue Jul 26 2005 kssingvo@suse.de
- update to version 3.6.6
* Tue Mar 29 2005 kssingvo@suse.de
- fix of config directory location (bugzilla#74539)
* Tue Feb  1 2005 kssingvo@suse.de
- new version 3.6.5: there was a bug in the linksys-ver2
* Thu Nov  4 2004 kssingvo@suse.de
- new version 3.6.4 and now maintained at sourceforge
* Sun Jan 11 2004 adrian@suse.de
- fix build as user
* Wed Aug 13 2003 kssingvo@suse.de
- fixed defaults (bugzilla#27701)
* Tue Jun 24 2003 kssingvo@suse.de
- upgraded to ddclient-3.6.3
* Tue Jan 14 2003 kssingvo@suse.de
- updated to ddclient-3.6.3beta3
* Mon Oct 28 2002 kssingvo@suse.de
- first shot.
